==> pfSense-base-21.05.3.txz: usr/local/sbin/pfSense-led.sh <==
#!/bin/sh
#
# pfSense-led.sh
#
# part of pfSense (https://www.pfsense.org)
# Copyright (c) 2018-2021 Rubicon Communications, LLC (Netgate)
# All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

#
# SG-1100
#
sg1100_led_booting() {
	if [ -c /dev/led/ok ]; then
		echo f1 > /dev/led/ok
	fi
}

sg1100_led_ready() {
	if [ -c /dev/led/ok ]; then
		echo 1 > /dev/led/ok
	fi
}

sg1100_led_update() {
	if [ -c /dev/led/ok ]; then
		echo f5 > /dev/led/ok
	fi
}

sg1100_led_update_off() {
	if [ -c /dev/led/ok ]; then
		echo 1 > /dev/led/ok
	fi
}

sg1100_led_updating() {
	sg1100_led_update
}

#
# SG-3100/SG-2100 common code
#
sgx100_led_booting() {
	local _gpiodev=${1}

	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 2 duty 100 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.0.pwm=0 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.1.pwm=0 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.2.pwm=0 > /dev/null
}

sgx100_led_ready() {
	local _gpiodev=${1}

	LED=0
	while [ ${LED} -le 8 ]; do
		/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} ${LED} duty 0 > /dev/null
		LED=$(( ${LED} + 1 ))
	done
	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 2 duty 20 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.1.pwm=1 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.2.pwm=1 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.0.T1-T3=1040 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.0.T2=520 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.pin.2.T4=3640 > /dev/null
}

sgx100_led_update() {
	local _gpiodev=${1}

	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 3 duty 150 > /dev/null
	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 4 duty 15 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.led.1.T1-T3=1040 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.pin.3.T4=3640 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.pin.4.T4=3640 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.led.1.pwm=0 > /dev/null
}

sgx100_led_update_off() {
	local _gpiodev=${1}

	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 3 duty 0 > /dev/null
	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 4 duty 0  > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.led.1.pwm=1 > /dev/null
}


#
# SG-3100
#
sg3100_gpiounit() {
	local _boardrev=$(/bin/kenv -q uboot.boardrev)

	# Both are 2 on 12.2-STABLE, but they may diverge again
	if [ "${_boardrev}" == "R100" ]; then
		echo "2"
	else
		echo "2"
	fi
}

sg3100_led_booting() {
	local _gpiodev=$(sg3100_gpiounit)

	sgx100_led_booting ${_gpiodev}
}

sg3100_led_ready() {
	local _gpiodev=$(sg3100_gpiounit)

	sgx100_led_ready ${_gpiodev}
}

sg3100_led_update() {
	local _gpiodev=$(sg3100_gpiounit)

	sgx100_led_update ${_gpiodev}
}

sg3100_led_update_off() {
	local _gpiodev=$(sg3100_gpiounit)

	sgx100_led_update_off ${_gpiodev}
}

sg3100_led_updating() {
	sg3100_led_update
}


#
# SG-2100
#
SG2100_GPIODEV=2
sg2100_led_booting() {
	sgx100_led_booting ${SG2100_GPIODEV}
}

sg2100_led_ready() {
	sgx100_led_ready ${SG2100_GPIODEV}
}

sg2100_led_update() {
	sgx100_led_update ${SG2100_GPIODEV}
}

sg2100_led_update_off() {
	sgx100_led_update_off ${SG2100_GPIODEV}
}

sg2100_led_updating() {
	sgx100_led_update ${SG2100_GPIODEV}
}


#
# SG-5100
#
sg5100_led_booting() {
	# Booting (red)
	/usr/local/sbin/SG-5100led 1 >/dev/null 2>&1
}

sg5100_led_ready() {
	# Boot finished (green)
	/usr/local/sbin/SG-5100led 3 >/dev/null 2>&1
}

sg5100_led_update() {
	# updates, green flashing
	/usr/local/sbin/SG-5100led 4 >/dev/null 2>&1
}

sg5100_led_update_off() {
	# No updates, green
	/usr/local/sbin/SG-5100led 3 >/dev/null 2>&1
}

sg5100_led_updating() {
	# Upgrade running during boot (LED blinking red)
	/usr/local/sbin/SG-5100led 2 >/dev/null 2>&1
}

#
# Netgate 4100 and 6100
#
6100_led_off() {
	local _leds="red1 green1 blue1 red2 green2 blue2 red3 green3 blue3"

	for led in ${_leds}; do
		echo 0 > /dev/led/${led}
	done
}

6100_led_booting() {
	6100_led_off
	# Fast blink blue on all LEDs
	echo f2 > /dev/led/blue1
	echo f2 > /dev/led/blue2
	echo f2 > /dev/led/blue3
}

6100_led_ready() {
	6100_led_off
	# Slow blink on left LED
	echo f9 > /dev/led/blue1
}

6100_led_update() {
	# Medium blink orange on center LED
	echo f4 > /dev/led/red2
	echo f4 > /dev/led/green2
	echo 0 > /dev/led/blue2
}

6100_led_update_off() {
	# Turn off center LED only
	echo 0 > /dev/led/red2
	echo 0 > /dev/led/green2
	echo 0 > /dev/led/blue2
}

6100_led_updating() {
	6100_led_off
	# Fast green blink on all LEDs
	echo f2 > /dev/led/green1
	echo f2 > /dev/led/green2
	echo f2 > /dev/led/green3
}


#
# Common code
#
led_booting() {
	case "$SYSTEM" in
	"SG-1100")
		sg1100_led_booting
		;;
	"SG-3100")
		sg3100_led_booting
		;;
	"SG-2100")
		sg2100_led_booting
		;;
	"SG-5100")
		sg5100_led_booting
		;;
	"4100"|"6100")
		6100_led_booting
		;;
	*)
		usage
		;;
	esac
}

led_ready() {
	case "$SYSTEM" in
	"SG-1100")
		sg1100_led_ready
		;;
	"SG-3100")
		sg3100_led_ready
		;;
	"SG-2100")
		sg2100_led_ready
		;;
	"SG-5100")
		sg5100_led_ready
		;;
	"4100"|"6100")
		6100_led_ready
		;;
	*)
		usage
		;;
	esac
}

led_update() {
	case "$SYSTEM" in
	"SG-1100")
		sg1100_led_update
		;;
	"SG-3100")
		sg3100_led_update
		;;
	"SG-2100")
		sg2100_led_update
		;;
	"SG-5100")
		sg5100_led_update
		;;
	"4100"|"6100")
		6100_led_update
		;;
	*)
		usage
		;;
	esac
}

led_update_off() {
	case "$SYSTEM" in
	"SG-1100")
		sg1100_led_update_off
		;;
	"SG-3100")
		sg3100_led_update_off
		;;
	"SG-2100")
		sg2100_led_update_off
		;;
	"SG-5100")
		sg5100_led_update_off
		;;
	"4100"|"6100")
		6100_led_update_off
		;;
	*)
		usage
		;;
	esac
}

led_updating() {
	case "$SYSTEM" in
	"SG-1100")
		sg1100_led_updating
		;;
	"SG-3100")
		sg3100_led_updating
		;;
	"SG-2100")
		sg2100_led_updating
		;;
	"SG-5100")
		sg5100_led_updating
		;;
	"4100"|"6100")
		6100_led_updating
		;;
	*)
		usage
		;;
	esac
}

usage() {
	echo "usage:"
	echo "pfSense-LED booting"
	echo "pfSense-LED ready"
	echo "pfSense-LED update [1|0]"
	echo "pfSense-LED updating"
	exit 1
}

if [ ${#} -lt 1 ]; then
	usage
fi
if [ "${1}" == update -a ${#} -lt 2 ]; then
	usage
fi
if [ "${1}" == update ]; then
	if [ ${2} -ne 0 -a ${2} -ne 1 ]; then
		usage
	fi
fi

_boardpn=$(/bin/kenv -q uboot.boardpn 2>/dev/null)
_maker=$(/bin/kenv -q smbios.system.maker 2>/dev/null)
_model=$(/bin/kenv -q smbios.system.product 2>/dev/null)
SYSTEM=""
if [ "${_boardpn%-*}" = "80500-0148" ]; then
	SYSTEM="SG-3100"
elif [ "${_model}" = "SG-5100" ]; then
	SYSTEM="SG-5100"
elif [ "${_maker}" = "Netgate" -a "${_model}" = "4100" ]; then
	SYSTEM="4100"
elif [ "${_maker}" = "Netgate" -a "${_model}" = "6100" ]; then
	SYSTEM="6100"
elif [ "${_model}" = "SG-2100" -o "${_model%-*}" = "80500-0205" -o "${_model}" = "mvebu_armada-37xx" ]; then
	_type=$(/usr/sbin/ofwdump -P model -R / 2>/dev/null)
	if [ "${_type}" = "Netgate SG-1100" ]; then
		SYSTEM="SG-1100"
	elif [ "${_type}" = "Netgate SG-2100" ]; then
		SYSTEM="SG-2100"
	fi
fi
if [ -z "${SYSTEM}" ]; then
	exit 1
fi

case ${1} in
booting)
	led_booting
	exit 0
	;;
ready)
	led_ready
	exit 0
	;;
updating)
	led_updating
	exit 0
	;;
update)
	;;
*)
	usage
esac

if [ ${2} -eq 0 ]; then
	led_update_off
else
	led_update
fi

exit 0

==> pfSense-base-22.01.txz: usr/local/sbin/pfSense-led.sh <==
#!/bin/sh
#
# pfSense-led.sh
#
# part of pfSense (https://www.pfsense.org)
# Copyright (c) 2018-2022 Rubicon Communications, LLC (Netgate)
# All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

#
# Netgate 1100
#
1100_led_booting() {
	if [ -c /dev/led/ok ]; then
		echo f1 > /dev/led/ok
	fi
}

1100_led_ready() {
	if [ -c /dev/led/ok ]; then
		echo 1 > /dev/led/ok
	fi
}

1100_led_update() {
	if [ -c /dev/led/ok ]; then
		echo f5 > /dev/led/ok
	fi
}

1100_led_update_off() {
	if [ -c /dev/led/ok ]; then
		echo 1 > /dev/led/ok
	fi
}

1100_led_updating() {
	1100_led_update
}

#
# Netgate 2100/3100 common code
#
x100_led_booting() {
	local _gpiodev=${1}

	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 2 duty 100 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.0.pwm=0 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.1.pwm=0 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.2.pwm=0 > /dev/null
}

x100_led_ready() {
	local _gpiodev=${1}

	LED=0
	while [ ${LED} -le 8 ]; do
		/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} ${LED} duty 0 > /dev/null
		LED=$(( ${LED} + 1 ))
	done
	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 2 duty 20 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.1.pwm=1 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.2.pwm=1 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.0.T1-T3=1040 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.led.0.T2=520 > /dev/null
	/sbin/sysctl -q dev.gpio.${_gpiodev}.pin.2.T4=3640 > /dev/null
}

x100_led_update() {
	local _gpiodev=${1}

	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 3 duty 150 > /dev/null
	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 4 duty 15 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.led.1.T1-T3=1040 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.pin.3.T4=3640 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.pin.4.T4=3640 > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.led.1.pwm=0 > /dev/null
}

x100_led_update_off() {
	local _gpiodev=${1}

	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 3 duty 0 > /dev/null
	/usr/sbin/gpioctl -f /dev/gpioc${_gpiodev} 4 duty 0  > /dev/null
	/sbin/sysctl dev.gpio.${_gpiodev}.led.1.pwm=1 > /dev/null
}


#
# SG-3100
#
3100_gpiounit() {
	local _boardrev=$(/bin/kenv -q uboot.boardrev)

	# Both are 2 on 12.2-STABLE, but they may diverge again
	if [ "${_boardrev}" == "R100" ]; then
		echo "2"
	else
		echo "2"
	fi
}

3100_led_booting() {
	local _gpiodev=$(3100_gpiounit)

	x100_led_booting ${_gpiodev}
}

3100_led_ready() {
	local _gpiodev=$(3100_gpiounit)

	x100_led_ready ${_gpiodev}
}

3100_led_update() {
	local _gpiodev=$(3100_gpiounit)

	x100_led_update ${_gpiodev}
}

3100_led_update_off() {
	local _gpiodev=$(3100_gpiounit)

	x100_led_update_off ${_gpiodev}
}

3100_led_updating() {
	3100_led_update
}


#
# Netgate 2100
#
SG2100_GPIODEV=2
2100_led_booting() {
	x100_led_booting ${SG2100_GPIODEV}
}

2100_led_ready() {
	x100_led_ready ${SG2100_GPIODEV}
}

2100_led_update() {
	x100_led_update ${SG2100_GPIODEV}
}

2100_led_update_off() {
	x100_led_update_off ${SG2100_GPIODEV}
}

2100_led_updating() {
	x100_led_update ${SG2100_GPIODEV}
}


#
# Netgate 5100
#
5100_led_booting() {
	# Booting (red)
	/usr/local/sbin/SG-5100led 1 >/dev/null 2>&1
}

5100_led_ready() {
	# Boot finished (green)
	/usr/local/sbin/SG-5100led 3 >/dev/null 2>&1
}

5100_led_update() {
	# updates, green flashing
	/usr/local/sbin/SG-5100led 4 >/dev/null 2>&1
}

5100_led_update_off() {
	# No updates, green
	/usr/local/sbin/SG-5100led 3 >/dev/null 2>&1
}

5100_led_updating() {
	# Upgrade running during boot (LED blinking red)
	/usr/local/sbin/SG-5100led 2 >/dev/null 2>&1
}

#
# Netgate 4100 and 6100
#
6100_led_off() {
	local _leds="red1 green1 blue1 amber1 red2 green2 blue2 amber2 red3 green3 blue3 amber3"

	for led in ${_leds}; do
		echo 0 > /dev/led/${led}
	done
}

6100_led_booting() {
	6100_led_off
	# Fast blink blue on all LEDs
	echo f2 > /dev/led/blue1
	echo f2 > /dev/led/blue2
	echo f2 > /dev/led/blue3
}

6100_led_ready() {
	6100_led_off
	# Slow blink on left LED
	echo f9 > /dev/led/blue1
}

6100_led_update() {
	# Medium blink orange on center LED
	echo f4 > /dev/led/amber2
	echo 0 > /dev/led/red2
	echo 0 > /dev/led/green2
	echo 0 > /dev/led/blue2
}

6100_led_update_off() {
	# Turn off center LED only
	echo 0 > /dev/led/amber2
	echo 0 > /dev/led/red2
	echo 0 > /dev/led/green2
	echo 0 > /dev/led/blue2
}

6100_led_updating() {
	6100_led_off
	# Fast green blink on all LEDs
	echo f2 > /dev/led/green1
	echo f2 > /dev/led/green2
	echo f2 > /dev/led/green3
}


#
# Common code
#
led_booting() {
	case "$SYSTEM" in
	"1100")
		1100_led_booting
		;;
	"2100")
		2100_led_booting
		;;
	"3100")
		3100_led_booting
		;;
	"5100")
		5100_led_booting
		;;
	"4100"|"6100")
		6100_led_booting
		;;
	*)
		usage
		;;
	esac
}

led_ready() {
	case "$SYSTEM" in
	"1100")
		1100_led_ready
		;;
	"2100")
		2100_led_ready
		;;
	"3100")
		3100_led_ready
		;;
	"5100")
		5100_led_ready
		;;
	"4100"|"6100")
		6100_led_ready
		;;
	*)
		usage
		;;
	esac
}

led_update() {
	case "$SYSTEM" in
	"1100")
		1100_led_update
		;;
	"2100")
		2100_led_update
		;;
	"3100")
		3100_led_update
		;;
	"5100")
		5100_led_update
		;;
	"4100"|"6100")
		6100_led_update
		;;
	*)
		usage
		;;
	esac
}

led_update_off() {
	case "$SYSTEM" in
	"1100")
		1100_led_update_off
		;;
	"2100")
		2100_led_update_off
		;;
	"3100")
		3100_led_update_off
		;;
	"5100")
		5100_led_update_off
		;;
	"4100"|"6100")
		6100_led_update_off
		;;
	*)
		usage
		;;
	esac
}

led_updating() {
	case "$SYSTEM" in
	"1100")
		1100_led_updating
		;;
	"2100")
		2100_led_updating
		;;
	"3100")
		3100_led_updating
		;;
	"5100")
		5100_led_updating
		;;
	"4100"|"6100")
		6100_led_updating
		;;
	*)
		usage
		;;
	esac
}

usage() {
	echo "usage:"
	echo "pfSense-LED booting"
	echo "pfSense-LED ready"
	echo "pfSense-LED update [1|0]"
	echo "pfSense-LED updating"
	exit 1
}

if [ ${#} -lt 1 ]; then
	usage
fi
if [ "${1}" == update -a ${#} -lt 2 ]; then
	usage
fi
if [ "${1}" == update ]; then
	if [ ${2} -ne 0 -a ${2} -ne 1 ]; then
		usage
	fi
fi

_boardpn=$(/bin/kenv -q uboot.boardpn 2>/dev/null)
_maker=$(/bin/kenv -q smbios.system.maker 2>/dev/null)
_model=$(/bin/kenv -q smbios.system.product 2>/dev/null)
SYSTEM=""
if [ "${_boardpn%-*}" = "80500-0148" ]; then
	SYSTEM="3100"
elif [ "${_model}" = "SG-5100" ]; then
	SYSTEM="5100"
elif [ "${_maker}" = "Netgate" -a "${_model}" = "4100" ]; then
	SYSTEM="4100"
elif [ "${_maker}" = "Netgate" -a "${_model}" = "6100" ]; then
	SYSTEM="6100"
elif [ "${_model}" = "SG-2100" -o "${_model%-*}" = "80500-0205" -o "${_model}" = "mvebu_armada-37xx" ]; then
	_type=$(/usr/sbin/ofwdump -P model -R / 2>/dev/null)
	if [ "${_type}" = "Netgate SG-1100" -o "${_type}" = "Netgate 1100" ]; then
		SYSTEM="1100"
	elif [ "${_type}" = "Netgate SG-2100" -o "${_type}" = "Netgate 2100" ]; then
		SYSTEM="2100"
	fi
fi
if [ -z "${SYSTEM}" ]; then
	exit 1
fi

case ${1} in
booting)
	led_booting
	exit 0
	;;
ready)
	led_ready
	exit 0
	;;
updating)
	led_updating
	exit 0
	;;
update)
	;;
*)
	usage
esac

if [ ${2} -eq 0 ]; then
	led_update_off
else
	led_update
fi

exit 0
